package cz.cvut.and.tutorial09;

import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.media.MediaPlayer;
import android.os.Binder;
import android.os.IBinder;
import android.util.Log;

public class MusicService extends Service {

	/**
	 * The {@link MusicService} binder.
	 * 
	 * @author cermaond
	 * 
	 */
	public class PlayerBinder extends Binder {
		/**
		 * Gets the instance of the running service.
		 * 
		 * @return The instance of the running service.
		 */
		public MusicService getInstance() {
			return MusicService.this;
		}
	}

	private static final String TAG = "MusicService";

	private static final int ID_NOTIFICATION = 1;

	MediaPlayer mPlayer;
	private PlayerBinder mBinder;
	private NotificationManager mNotificationManager;

	@Override
	public void onCreate() {
		Log.d(TAG, "onCreate()");

		mPlayer = MediaPlayer.create(this, R.raw.emer_mulholland_the_pure_heir);
		mBinder = new PlayerBinder();

		mNotificationManager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);
	}

	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
		Log.d(TAG, "onStartCommand()");

		Log.d(TAG, "Playback started.");
		mPlayer.start();

		startForeground(ID_NOTIFICATION, createNotification(R.string.playing));

		return START_STICKY;
	}

	/**
	 * Creates new notification.
	 * 
	 * @param titleResId
	 *          The title for the notification.
	 * @return The notification instance.
	 */
	public Notification createNotification(int titleResId) {
		String title = getString(titleResId);
		String contentText = getString(R.string.emer_mulholland_the_pure_heir);

		Notification notification = new Notification();
		notification.icon = R.drawable.ic_stat_notification;
		notification.tickerText = title + ": " + contentText;
		notification.flags |= Notification.FLAG_NO_CLEAR;

		Intent notificationIntent = new Intent(this, Tutorial09Activity.class);
		PendingIntent contentIntent = PendingIntent.getActivity(this, 0,
				notificationIntent, PendingIntent.FLAG_UPDATE_CURRENT);

		notification.setLatestEventInfo(this, title, contentText, contentIntent);

		return notification;
	}

	@Override
	public IBinder onBind(Intent intent) {
		return mBinder;
	}

	/**
	 * Resumes the playback if currently paused.
	 */
	public void resume() {
		if (!mPlayer.isPlaying()) {
			Log.d(TAG, "Playback resumed at: " + mPlayer.getCurrentPosition());
			mNotificationManager.notify(ID_NOTIFICATION,
					createNotification(R.string.playing));
			mPlayer.start();
		}
	}

	/**
	 * Pauses the playback if currently playing.
	 */
	public void pause() {
		if (mPlayer.isPlaying()) {
			Log.d(TAG, "Playback paused at: " + mPlayer.getCurrentPosition());
			mNotificationManager.notify(ID_NOTIFICATION,
					createNotification(R.string.paused));
			mPlayer.pause();
		}
	}

	/**
	 * Whether or not is the music playing.
	 * 
	 * @return True if playing, false otherwise.
	 */
	public boolean isPlaying() {
		return mPlayer.isPlaying();
	}

	/**
	 * Gets current playback position.
	 * 
	 * @return The position in milliseconds.
	 */
	public long getCurrentPosition() {
		return mPlayer.getCurrentPosition();
	}

	@Override
	public void onDestroy() {
		Log.d(TAG, "onDestroy()");

		mNotificationManager.cancel(ID_NOTIFICATION);
		Log.d(TAG, "Playback stopped: " + mPlayer.getCurrentPosition());
		mPlayer.stop();
		mPlayer.release();
	}

}
