package cz.cvut.and.tutorial09;

import cz.cvut.and.tutorial09.MusicService.PlayerBinder;
import android.app.Activity;
import android.content.ComponentName;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

public class Tutorial09Activity extends Activity {

	private Button mBtnPause;

	private Intent mMusicServiceIntent;
	private MusicService.PlayerBinder mMusicServiceBinder;
	private MusicService mMusicService;

	private ServiceConnection mMusicServiceConnection = new ServiceConnection() {
		@Override
		public void onServiceConnected(ComponentName name, IBinder service) {
			mMusicServiceBinder = (PlayerBinder) service;
			mMusicService = mMusicServiceBinder.getInstance();
			if (mMusicService.isPlaying()) {
				mBtnPause.setVisibility(View.VISIBLE);
				mBtnPause.setText(R.string.pause);
			} else {
				if (mMusicService.getCurrentPosition() <= 0) {
					mBtnPause.setVisibility(View.INVISIBLE);
				} else {
					mBtnPause.setVisibility(View.VISIBLE);
					mBtnPause.setText(R.string.resume);
				}
			}
		}

		@Override
		public void onServiceDisconnected(ComponentName name) {
		}
	};

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		final Button btnStart = (Button) findViewById(R.id.btnStart);
		mBtnPause = (Button) findViewById(R.id.btnPause);
		final Button btnStop = (Button) findViewById(R.id.btnStop);
		btnStop.setEnabled(false);

		mMusicServiceIntent = new Intent(Tutorial09Activity.this,
				MusicService.class);

		btnStart.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				startService(mMusicServiceIntent);
				bindMusicService();
				mBtnPause.setText(R.string.pause);
				mBtnPause.setVisibility(View.VISIBLE);
				btnStart.setEnabled(false);
				btnStop.setEnabled(true);
			}
		});

		mBtnPause.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				if (mMusicService.isPlaying()) {
					mBtnPause.setText(R.string.resume);
					mMusicService.pause();
				} else {
					mBtnPause.setText(R.string.pause);
					mMusicService.resume();
				}
			}
		});

		btnStop.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				unbindMusicService();
				stopService(mMusicServiceIntent);
				mBtnPause.setVisibility(View.INVISIBLE);
				btnStart.setEnabled(true);
				btnStop.setEnabled(false);
			}
		});
	}

	@Override
	protected void onPause() {
		super.onPause();
		if(mMusicServiceBinder != null) {
			unbindMusicService();
		}
	}

	@Override
	protected void onResume() {
		super.onResume();
		bindMusicService();
	}

	/**
	 * Binds the {@link MusicService}.
	 */
	private void bindMusicService() {
		bindService(mMusicServiceIntent, mMusicServiceConnection, 0);
	}

	/**
	 * Unbinds the {@link MusicService};
	 */
	private void unbindMusicService() {
		unbindService(mMusicServiceConnection);
		mMusicServiceBinder = null;
		mMusicService = null;
	}
}
